@@ -1,7 +1,3 @@
-#
-# $Id$
-#
-
 package ExtUtils::Depends;
 
 use strict;
@@ -12,7 +8,7 @@ use File::Find;
 use File::Spec;
 use Data::Dumper;
 
-our $VERSION = '0.403';
+our $VERSION = '0.8000';
 
 sub import {
 	my $class = shift;
@@ -127,7 +123,7 @@ sub save_config {
 		inc => join (" ", @{ $self->{inc} }),
 		libs => $self->{libs},
 		typemaps => [ map { basename $_ } @{ $self->{typemaps} } ],
-		deps => [keys %{ $self->{deps} }],
+		deps => [sort keys %{ $self->{deps} }],
 	}], ['self']);
 	print $file <<'EOF';
 
@@ -178,7 +174,8 @@ sub load {
 	my $dep = shift;
 	my @pieces = split /::/, $dep;
 	my @suffix = qw/ Install Files /;
-	my $relpath = File::Spec->catfile (@pieces, @suffix) . '.pm';
+	# not File::Spec - see perldoc -f require
+	my $relpath = join('/', @pieces, @suffix) . '.pm';
 	my $depinstallfiles = join "::", @pieces, @suffix;
 	eval {
 		require $relpath 
@@ -222,12 +219,14 @@ sub load {
 	{
 		instpath => $instpath,
 		typemaps => \@typemaps,
-		inc      => "-I$instpath $inc",
+		inc      => "-I". _quote_if_space($instpath) ." $inc",
 		libs     => $libs,
 		deps     => \@deps,
 	}
 }
 
+sub _quote_if_space { $_[0] =~ / / ? qq{"$_[0]"} : $_[0] }
+
 sub load_deps {
 	my $self = shift;
 	my @load = grep { not $self->{deps}{$_} } keys %{ $self->{deps} };
@@ -271,7 +270,7 @@ sub get_makefile_vars {
 	my @incbits = map { split } @{ $self->{inc} };
 	my @libsbits = split /\s+/, $self->{libs};
 	my @typemaps = @{ $self->{typemaps} };
-	foreach my $d (keys %{ $self->{deps} }) {
+	foreach my $d (sort keys %{ $self->{deps} }) {
 		my $dep = $self->{deps}{$d};
 		#push @defbits, @{ $dep->{defines} };
 		push @incbits, @{ $dep->{defines} } if $dep->{defines};
@@ -365,7 +364,9 @@ sub find_extra_libs {
 		}, map { -d $_ ? ($_) : () } @INC); # only extant dirs
 
 		if ($matching_file && -f $matching_file) {
-			push @found_libs, ('-L' . $matching_dir, '-l' . $stem);
+			push @found_libs,
+				'-L' . _quote_if_space($matching_dir),
+				'-l' . $stem;
 			# Android's linker ignores the RTLD_GLOBAL flag
 			# and loads everything as if under RTLD_LOCAL.
 			# What this means in practice is that modules need
